pub struct GuidedTourDto {
pub completed_steps: Vec<String>,
pub paused: bool,
}Expand description
The information about a users tour sent to the frontend.
Fields
completed_steps: Vec<String>IDs of the steps the user has already completed.
paused: boolBoolean specifying if the tour is paused for this user.